<ScrollView class="peek-home-screen-background">
    <GridLayout class="peek-home-screen"
                [rows]="appButtonGridRows()"
                columns="*, *">
        <Label class="home-screen-message"
               *ngIf="!appDetails.length"
               text="No Plugins Installed">

        </Label>
        <GridLayout class="home-screen-icon"
                    *ngFor="let i=index; let app of appDetails"
                    rows="*,auto"
                    columns="*"
                    [row]="appButtonGridRowIndex(i)"
                    [col]="i % 2"
                    [nsRouterLink]="[app.resourcePath]">
            <Image class="home-screen-image"
                   src="~{{app.pluginIconPath}}"></Image>
            <Label class="home-screen-title"
                   row="1" textWrap="true"
                   [text]="app.title"></Label>
        </GridLayout>
    </GridLayout>
</ScrollView>
